@@ -1,13 +1,16 @@
 package Perl::osnames;
 
-our $DATE = '2014-12-19'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-02-10'; # DATE
+our $DIST = 'Perl-osnames'; # DIST
+our $VERSION = '0.120'; # VERSION
 
 use strict;
 use warnings;
 
 use Exporter qw(import);
-our @EXPORT_OK = qw($data is_unix is_posix);
+our @EXPORT_OK = qw($data is_unix is_posix
+                    $RE_OS_IS_KNOWN $RE_OS_IS_POSIX $RE_OS_IS_UNIX);
 
 our $data = [map {
     chomp;
@@ -69,28 +72,45 @@ _
 #use Data::Dump::Color;
 #dd $data;
 
+our $RE_OS_IS_KNOWN = do {
+    my $re = join "|", map { $_->[0] } @$data;
+    qr/\A(?:$re)\z/;
+};
+
+our $RE_OS_IS_POSIX = do {
+    my @os;
+  OS:
+    for my $rec (@$data) {
+        for (@{$rec->[1]}) {
+            do { push @os, $rec->[0]; next OS } if $_ eq 'posix';
+        }
+    }
+    my $re = join("|", @os);
+    qr/\A(?:$re)\z/;
+};
+
+our $RE_OS_IS_UNIX = do {
+    my @os;
+  OS:
+    for my $rec (@$data) {
+        for (@{$rec->[1]}) {
+            do { push @os, $rec->[0]; next OS } if $_ eq 'unix';
+        }
+    }
+    my $re = join("|", @os);
+    qr/\A(?:$re)\z/;
+};
+
 sub is_posix {
     my $os = shift || $^O;
-    for my $rec (@$data) {
-        next unless $rec->[0] eq $os;
-        for (@{$rec->[1]}) {
-            return 1 if $_ eq 'posix';
-        }
-        return 0;
-    }
-    undef;
+    return undef unless $os =~ $RE_OS_IS_KNOWN;
+    $os =~ $RE_OS_IS_POSIX ? 1:0;
 }
 
 sub is_unix {
     my $os = shift || $^O;
-    for my $rec (@$data) {
-        next unless $rec->[0] eq $os;
-        for (@{$rec->[1]}) {
-            return 1 if $_ eq 'unix';
-        }
-        return 0;
-    }
-    undef;
+    return undef unless $os =~ $RE_OS_IS_KNOWN;
+    $os =~ $RE_OS_IS_UNIX ? 1:0;
 }
 
 1;
@@ -108,7 +128,7 @@ Perl::osnames - List possible $^O ($OSNAME) values, with description
 
 =head1 VERSION
 
-This document describes version 0.11 of Perl::osnames (from Perl distribution Perl-osnames), released on 2014-12-19.
+This document describes version 0.120 of Perl::osnames (from Perl distribution Perl-osnames), released on 2020-02-10.
 
 =head1 DESCRIPTION
 
@@ -151,6 +171,12 @@ An arrayref of records (arrayrefs), each structured as:
 
  [$name, \@tags, $description]
 
+=head2 $RE_OS_IS_KNOWN
+
+=head2 $RE_OS_IS_POSIX
+
+=head2 $RE_OS_IS_UNIX
+
 =head1 FUNCTIONS
 
 None are exported by default, but they are exportable.
@@ -167,6 +193,22 @@ Check whether C<$os> (defaults to C<$^O> if not specified) is Unix (checked by
 the existence of C<unix> tag on the OS's record in C<$data>). Will return 0, 1,
 or undef if C<$os> is unknown.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Perl-osnames>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Perl-osnames>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perl-osnames>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 L<perlvar>
@@ -186,29 +228,13 @@ L<App::osnames>, the original reason for Perl::osnames. With this CLI tool you
 can grep OS names by name, tag, or description, e.g. C<osnames solaris> or
 C<osnames posix>.
 
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/Perl-osnames>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/perlancar/perl-Perl-osnames>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perl-osnames>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
